fars_map_state: Map of Accidents

Description Usage Arguments Value Examples

Description

This function prints maps of US states with dots representing the location of accidents for a given state in a given year. The user provides the state and year that will be mapped.

Usage

1
fars_map_state(state.num, year)

Arguments

state.num

An integer that corresponds to a state.

year

An integer that corresponds to a year.

Value

This function plots a map of the locations of crashes for the chosen state in the chosen year.

Examples

1
2

Andrew-Clappison/SDinRcourse3week4 documentation built on June 13, 2019, 5:41 p.m.