fars_read: Read File

Description Usage Arguments Value Examples

Description

This function is used to read in accident data files.

Usage

1
fars_read(filename)

Arguments

filename

A string that corresponds to the name of the file to be opened.

Value

The function returns the contents of the filename in the form of a data frame. If the filename does not exist, the user will be notified.

Examples

1
2
fars_read("accident_2013.csv.bz2")
fars_read("accident_2014.csv.bz2")

Andrew-Clappison/SDinRcourse3week4 documentation built on June 13, 2019, 5:41 p.m.