fars_read_years: Get data for Years

Description Usage Arguments Value Examples

Description

This function is used to select the relevant columns of data from years specified by the user. This data is used by the function fars_summarize_years().

Usage

1

Arguments

years

An integer or string or list of integers and strings that correspond to years.

Value

This function returns a list of data frames that have a column for month and year of each accident. If there is a problem reading in or using the data an error will be returned.

Examples

1
2
3
fars_read_years(c(2013, 2014))
fars_read_years(c("2013", "2015"))
fars_read_years(2014)

Andrew-Clappison/SDinRcourse3week4 documentation built on June 13, 2019, 5:41 p.m.