fars_summarize_years: Summarize Accident Data

Description Usage Arguments Value Examples

Description

This is a function that summarizes accident data by totaling the number of accidents in the country by month.

Usage

1

Arguments

years

A integer or string or a list of integers or strings that are years.

Value

The function returns a tibble. There is a column for month, and for each year provided there is a column for the number of accidents in the US for that month.

Examples

1
2

Andrew-Clappison/SDinRcourse3week4 documentation built on June 13, 2019, 5:41 p.m.