make_filename: Create Filename

Description Usage Arguments Value Examples

Description

This function creates the file name for the accident data for a given year.

Usage

1

Arguments

year

An integer or string that corresponds to a year.

Value

The corresponding filename as a string for a given year.

Examples

1
2

Andrew-Clappison/SDinRcourse3week4 documentation built on June 13, 2019, 5:41 p.m.