Description Usage Arguments Value Examples
This function prints maps of US states with dots representing the location of accidents for a given state in a given year. The user provides the state and year that will be mapped.
1 | fars_map_state(state.num, year)
|
state.num |
An integer that corresponds to a state. |
year |
An integer that corresponds to a year. |
This function plots a map of the locations of crashes for the chosen state in the chosen year.
1 2 | fars_map_state(1,2013)
fars_map_state(6,2015)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.