Description Usage Arguments Value Examples
This function is used to read in accident data files.
1 | fars_read(filename)
|
filename |
A string that corresponds to the name of the file to be opened. |
The function returns the contents of the filename in the form of a data frame. If the filename does not exist, the user will be notified.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.