Description Usage Arguments Value Examples
This function is used to select the relevant columns of data from years specified by the user. This data is used by the function fars_summarize_years().
1 | fars_read_years(years)
|
years |
An integer or string or list of integers and strings that correspond to years. |
This function returns a list of data frames that have a column for month and year of each accident. If there is a problem reading in or using the data an error will be returned.
1 2 3 | fars_read_years(c(2013, 2014))
fars_read_years(c("2013", "2015"))
fars_read_years(2014)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.