Description Usage Arguments Value Examples
This is a function that summarizes accident data by totaling the number of accidents in the country by month.
1 | fars_summarize_years(years)
|
years |
A integer or string or a list of integers or strings that are years. |
The function returns a tibble. There is a column for month, and for each year provided there is a column for the number of accidents in the US for that month.
1 2 | fars_summarize_years(2013)
fars_summarize_years(c(2013,2014,2015))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.