Description Usage Arguments Value Examples
This function creates the file name for the accident data for a given year.
1 | make_filename(year)
|
year |
An integer or string that corresponds to a year. |
The corresponding filename as a string for a given year.
1 2 | make_filename("2013")
make_filename(2015)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.